@@ -99,7 +99,7 @@ def _exec(args, env):
         sys.exit(process.returncode)
 
 def _run(app_path, extra_env=None):
-    python_exe = install_deps(app_path)
+    python_exe = build(app_path)
 
     args, working_directory = _app_exec_info(app_path, python_exe=python_exe)
 
@@ -119,7 +119,7 @@ def simulate(app_path):
 
 
 def run(app_path, hostname):
-    print 'Connecting to Pi...'
+    print 'tbtool: Connecting to Pi...'
 
     session = SSHSession(hostname)
 
@@ -129,20 +129,20 @@ def run(app_path, hostname):
         app_install_location = '/tmp/tide/%s' % app_name
         app_install_folder = os.path.dirname(app_install_location)
 
-        print 'Setting up Pi...'
+        print 'tbtool: Setting up Pi...'
         session.exec_command('rm -rf "%s"' % app_install_location)
         session.exec_command('mkdir -p "%s"' % app_install_folder)
 
-        print 'Copying app to %s...' % app_install_location
+        print 'tbtool: Copying app to %s...' % app_install_location
         session.exec_command('rm -rf "%s"' % app_install_location)
         session.put_dir(app_path, app_install_location)
 
-        print 'Starting app...'
+        print 'tbtool: Starting app...'
         session.exec_command('tbopen "%s"' % app_install_location)
     finally:
         session.close()
 
-def install_deps(app_path):
+def build(app_path):
     '''
     Installs the dependencies in requirements.txt into a virtualenv in the app directory
     Returns the path to the python executable that should be used to run the app.
@@ -174,14 +174,30 @@ def install_deps(app_path):
     except (OSError, subprocess.CalledProcessError):
         # we've got to build the virtualenv
         clean(app_path)
+        print 'tbtool: Creating virtualenv...'
         virtualenv.create_environment(venv_path, site_packages=True,)
 
+        # ignore the virtualenv when the app is tracked with git
+        gitignore_path = os.path.join(venv_path, '.gitignore')
+        with open(gitignore_path, 'w') as f:
+            f.write(textwrap.dedent('''
+                # Generated by tbtool.
+
+                # Don't commit virtualenvs to git, because they contain platform-specific
+                # code and don't relocate well.
+
+                # '*' matches everything in this folder
+
+                *
+                '''))
+
     requirements_unchanged_since_last_run = (
         os.path.isfile(venv_previous_requirements_path)
         and filecmp.cmp(requirements_txt_path, venv_previous_requirements_path)
     )
 
     if not requirements_unchanged_since_last_run:
+        print 'tbtool: Installing dependencies into virtualenv...'
         venv_pip_path = os.path.join(venv_bin_dir, 'pip')
 
         env = os.environ.copy()
@@ -215,14 +231,17 @@ def install(app_path, hostname):
 
         app_install_location = '/apps/%s' % app_name
 
-        print 'Copying app to %s...' % app_install_location
+        print 'tbtool: Copying app to %s...' % app_install_location
         session.exec_command('rm -rf "%s"' % app_install_location)
         session.put_dir(app_path, app_install_location)
 
-        print 'Restarting springboard...'
+        print 'tbtool: Preparing app...'
+        session.exec_command('tbtool build "%s"' % app_install_location)
+
+        print 'tbtool: Restarting springboard...'
         session.exec_command('tbopen /apps/home')
 
-        print 'App installed.'
+        print 'tbtool: App installed.'
     finally:
         session.close()
 
@@ -235,9 +254,10 @@ def main():
     args = docopt(textwrap.dedent('''
         Usage: 
           tbtool [-v] simulate <app>
-          tbtool [-v] clean <app>
           tbtool [-v] run <app> <hostname>
           tbtool [-v] install <app> <hostname>
+          tbtool [-v] build <app>
+          tbtool [-v] clean <app>
           tbtool [-v] tingbot_run <app>
           tbtool -h|--help
 
@@ -246,10 +266,14 @@ def main():
 
         Commands:
           simulate <app>            Runs the app in the simulator
-          clean <app>               Removes temporary files in the app
           run <app> <hostname>      Runs the app on the Tingbot specified by hostname
           install <app> <hostname>  Installs the app on the Tingbot specified by
                                     hostname
+          build <app>               If the app contains a requirements.txt file, creates
+                                    a virtualenv with those packages installed. Not
+                                    usually required to be called directly, building is
+                                    automatic when using 'simulate', 'run' and 'install'.
+          clean <app>               Removes temporary files in the app
           tingbot_run <app>         Used by tbprocessd to run Tingbot apps on the
                                     Tingbot itself. Users should probably use `tbopen'
                                     instead.
@@ -263,12 +287,14 @@ def main():
 
         if args['simulate']:
             return simulate(app_path)
-        elif args['clean']:
-            return clean(app_path)
         elif args['run']:
             return run(app_path, args['<hostname>'])
         elif args['install']:
             return install(app_path, args['<hostname>'])
+        elif args['build']:
+            return build(app_path)
+        elif args['clean']:
+            return clean(app_path)
         elif args['tingbot_run']:
             return tingbot_run(app_path)
     except Exception as e:
